@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Dump;
 
-our $DATE = '2015-07-30'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010;
 use strict;
@@ -46,10 +46,18 @@ _
             schema => 'str*',
             req => 1,
             pos => 0,
+            cmdline_aliases => {f=>{}},
         },
         libs => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'lib',
             summary => 'Libraries to unshift to @INC when running script',
             schema  => ['array*' => of => 'str*'],
+            cmdline_aliases => {I=>{}},
+        },
+        skip_detect => {
+            schema => ['bool', is=>1],
+            cmdline_aliases => {D=>{}},
         },
     },
 };
@@ -62,11 +70,16 @@ sub dump_perinci_cmdline_script {
     my %args = @_;
 
     my $filename = $args{filename} or return [400, "Please specify filename"];
-    my $detres = Perinci::CmdLine::Util::detect_perinci_cmdline_script(
-        filename => $filename);
-    return $detres if $detres->[0] != 200;
-    return [412, "File '$filename' is not script using Perinci::CmdLine (".
-        $detres->[3]{'func.reason'}.")"] unless $detres->[2];
+    my $detres;
+    if ($args{skip_detect}) {
+        $detres = [200, "OK (skip_detect)", 1, {"func.reason" => "skip detect, forced"}];
+    } else {
+        $detres = Perinci::CmdLine::Util::detect_perinci_cmdline_script(
+            filename => $filename);
+        return $detres if $detres->[0] != 200;
+        return [412, "File '$filename' is not script using Perinci::CmdLine (".
+                    $detres->[3]{'func.reason'}.")"] unless $detres->[2];
+    }
 
     my $res = [200, "OK", undef, {
         'func.detect_res' => $detres,
@@ -162,16 +175,15 @@ Perinci::CmdLine::Dump - Run a Perinci::CmdLine-based script but only to dump th
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2015-07-30.
+This document describes version 0.06 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2016-10-27.
 
 =head1 FUNCTIONS
 
 
 =head2 dump_perinci_cmdline_script(%args) -> [status, msg, result, meta]
 
-{en_US Run a Perinci::CmdLine-based script but only to dump the object}.
+Run a Perinci::CmdLine-based script but only to dump the object.
 
-{en_US 
 This function runs a CLI script that uses C<Perinci::CmdLine> (or its variant
 C<Perinci::CmdLine::Lite> or C<Perinci::CmdLine::Any>) but monkey-patches
 C<Perinci::CmdLine::Base> beforehand so that C<run()> will dump the object and
@@ -192,7 +204,8 @@ that script refers to function URL C</main> (which might mean that function
 metadata is embedded in the script itself and not in a separate module), will
 also dump the target function's metadata in C<func.meta> in this function's
 result metadata.
-}
+
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -200,11 +213,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<filename>* => I<str>
 
-{en_US Path to the script}.
+Path to the script.
 
 =item * B<libs> => I<array[str]>
 
-{en_US Libraries to unshift to @INC when running script}.
+Libraries to unshift to @INC when running script.
+
+=item * B<skip_detect> => I<bool>
 
 =back
 
@@ -241,7 +256,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
